from graphviz import Digraph
import numpy as np
from formatting import human_format, formatted_human_readable


color_scale = ['#4192a9', '#33bb6b', '#67cd25', '#dfb717', '#dfb717', '#d4bc26', '#c9be35', '#bcbb46', '#bcbb46', '#cba62f', '#d67f1b', '#e14a08']

def create_graph(workflow_mined, start_end, activity_count, selected=None, transition='frequency'):
    starts = set(start_end[start_end['start_end']=='start']['step'])
    ends = set(start_end[start_end['start_end']=='end']['step'])
    
    max_weight = workflow_mined['weight'].max()
    min_weight = workflow_mined['weight'].min()
    max_count = activity_count['frequency'].max()
    
    unique_nodes = workflow_mined['source'].append(workflow_mined['target']).unique()
    unique_nodes_dict = {unique_nodes[i]: str(i) for i in range(len(unique_nodes))}
    dot = Digraph()
    
    for node in activity_count.sort_values('frequency')['step']:
        count = activity_count[activity_count['step']==node]['frequency'].iloc[0]
        color = color_scale[int((count-1)*len(color_scale)/(max_count))]
        if node in starts:
            shape = 'diamond'
        elif node in ends:
            shape = 'house'
        else:
            shape = 'box'
        dot.node(unique_nodes_dict[node], node, color='white', shape=shape, style="filled", 
                     fillcolor=color, fontname='Helvetica Neue', fontcolor='white')
    
    for index, edge in workflow_mined.iterrows():
        color = 'black'
        if transition == 'frequency':
            dot.edge(unique_nodes_dict[edge['source']], unique_nodes_dict[edge['target']], color=color, label=human_format(int(edge['weight'])), fontname='Helvetica Neue')
        elif transition == 'time':
            dot.edge(unique_nodes_dict[edge['source']], unique_nodes_dict[edge['target']], color=color, label=formatted_human_readable(int(edge['weight'])), fontname='Helvetica Neue')
    
    return dot.source, unique_nodes, max_count