Process Mining often starts with very large log files that can seem at first glance inextricably jumbled and too complex to parse. The process of discovery is the complex task of making sense of the data. Achieving this is done using manual filters and selections to discriminate signal from noise, alongside algorithms that build a synthetic representation of a process. The implementation of these steps is taken from the [pm4py library](article:9).

# 'Directly Follows' Graph

Making sense of this kind of data requires a business understanding of the process, and the right tools to explore the data in a meaningful and visual way. Visually seeing the process is essential to build an insightful representation of what is going on.

The 'directly follows' graph is an exhaustive representation of the data where each activity is plotted and arrows are drawn between each activity and the activities that follow. A different arrow is drawn to represent each distinct transition, and additional information is displayed alongside each arrow including frequency (the number of occurrences of the transition in the data) or performance (the average time of completion of this transition).

# Selecting and Filtering

The source data may contain some activities that do not provide any insight into the process, because they are not impactful in the execution of the process, or are just automatically generated after or before another activity. Removing these activities enables us to focus on the actual core process. Therefore various filtering actions are initially performed to clean the data and keep only analytically relevant steps. This work combines business knoweldge of the process with statistical insights.

Filtering of the traces is necessary to further understand a process. Standard ways of filtering traces include:

-  **Time** : select traces occurring within a set timeframe.
-  **Start/End Activity** : select traces that start/end with a given activity.
-  **Case Performance** : select traces that were the fastest/slowest.
-  **Additional Numerical or Categorical Filters** : select traces that belong to set ranges or categories of attributes.

A 'variant' is defined as a unique sequence of steps and might occur multiple times in the data. Variants that exhibit the largest number of occurrences may represent the standard execution of the process, while unique variants are likely outliers. A visual representation of all traces (with no filtering) is often unmanageable because the number of possible transitions can become extremely large. Choosing to represent only the most frequent variants is one of many effective steps to better understand the underly processes.

# Inductive Miner

Automatic mining of process logs enables the creation of a synthetic representation of a process. The inductive miner algorithm handles the log data and outputs a graphical model of the process, specifically a [Petri Net](https://en.wikipedia.org/wiki/Petri_net). Comprehensive documentation about Petri nets and the inductive miner algorithm can be found in the relevant Python library and the 'Process Mining, Data Science in Action' book listed in the [resources](article:9). This representation is a key input for the [conformance check operations](article:4) which evaluates what share of traces conform to a predefined process.

